SparseVector class final

A sparse vector represented by matching index and value lists.

Inheritance

Constructors

SparseVector({required Iterable<int> indices, required Iterable<num> values})
Creates a sparse vector.

Properties

hashCode int
The hash code for this object.
no setterinherited
indices List<int>
Non-zero vector positions.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<num>
Values at the matching indices.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited