PayloadIndexInfo class final
Information reported for one payload field index.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pointsCount → int?
-
Points currently covered by this index, when Qdrant reports the count.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema → PayloadSchemaType
-
The indexed field's data type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited