SparseVector class final
A sparse vector represented by matching index and value lists.
- Inheritance
-
- Object
- VectorValue
- SparseVector
Constructors
-
SparseVector({required Iterable<
int> indices, required Iterable<num> values}) - Creates a sparse vector.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited